package org.acra;

import android.app.Application;
import android.content.SharedPreferences;
import android.os.Build;
import java.io.FileInputStream;
import java.io.IOException;
import java.util.Objects;
import org.acra.annotation.ReportsCrashes;
import org.acra.config.ACRAConfiguration;
import org.acra.config.ACRAConfigurationException;
import org.acra.config.ConfigurationBuilder;
import org.acra.legacy.LegacyFileHandler;
import org.acra.log.ACRALog;
import org.acra.log.AndroidLogDelegate;
import org.acra.prefs.SharedPreferencesFactory;
import org.acra.util.ApplicationStartupProcessor;
import org.acra.util.IOUtils;

public final class ACRA {
    private static final String ACRA_PRIVATE_PROCESS_NAME = ":acra";
    public static boolean DEV_LOGGING = false;
    public static final String LOG_TAG = "ACRA";
    public static final String PREF_ALWAYS_ACCEPT = "acra.alwaysaccept";
    public static final String PREF_DISABLE_ACRA = "acra.disable";
    public static final String PREF_ENABLE_ACRA = "acra.enable";
    public static final String PREF_ENABLE_DEVICE_ID = "acra.deviceid.enable";
    public static final String PREF_ENABLE_SYSTEM_LOGS = "acra.syslog.enable";
    public static final String PREF_LAST_VERSION_NR = "acra.lastVersionNr";
    public static final String PREF_USER_EMAIL_ADDRESS = "acra.user.email";
    private static ACRAConfiguration configProxy;
    private static ErrorReporter errorReporterSingleton;
    public static ACRALog log = new AndroidLogDelegate();
    private static Application mApplication;
    private static SharedPreferences.OnSharedPreferenceChangeListener mPrefListener;

    private ACRA() {
    }

    public static SharedPreferences getACRASharedPreferences() {
        ACRAConfiguration aCRAConfiguration = configProxy;
        if (aCRAConfiguration != null) {
            return new SharedPreferencesFactory(mApplication, aCRAConfiguration).create();
        }
        throw new IllegalStateException("Cannot call ACRA.getACRASharedPreferences() before ACRA.init().");
    }

    public static ACRAConfiguration getConfig() {
        ACRAConfiguration aCRAConfiguration = configProxy;
        if (aCRAConfiguration != null) {
            return aCRAConfiguration;
        }
        throw new IllegalStateException("Cannot call ACRA.getConfig() before ACRA.init().");
    }

    private static String getCurrentProcessName() {
        try {
            return IOUtils.streamToString(new FileInputStream("/proc/self/cmdline")).trim();
        } catch (IOException unused) {
            return null;
        }
    }

    public static ErrorReporter getErrorReporter() {
        ErrorReporter errorReporter = errorReporterSingleton;
        if (errorReporter != null) {
            return errorReporter;
        }
        throw new IllegalStateException("Cannot access ErrorReporter before ACRA#init");
    }

    public static void init(Application application) {
        if (((ReportsCrashes) application.getClass().getAnnotation(ReportsCrashes.class)) == null) {
            ACRALog aCRALog = log;
            String str = LOG_TAG;
            aCRALog.e(str, "ACRA#init(Application) called but no ReportsCrashes annotation on Application " + application.getPackageName());
            return;
        }
        init(application, new ConfigurationBuilder(application));
    }

    public static boolean isACRASenderServiceProcess() {
        String currentProcessName = getCurrentProcessName();
        if (DEV_LOGGING) {
            ACRALog aCRALog = log;
            String str = LOG_TAG;
            aCRALog.d(str, "ACRA processName='" + currentProcessName + '\'');
        }
        return currentProcessName != null && currentProcessName.endsWith(ACRA_PRIVATE_PROCESS_NAME);
    }

    public static boolean isInitialised() {
        return configProxy != null;
    }

    public static void setLog(ACRALog aCRALog) {
        Objects.requireNonNull(aCRALog, "ACRALog cannot be null");
        log = aCRALog;
    }

    /* access modifiers changed from: private */
    public static boolean shouldDisableACRA(SharedPreferences sharedPreferences) {
        boolean z = true;
        try {
            if (sharedPreferences.getBoolean(PREF_ENABLE_ACRA, true)) {
                z = false;
            }
            return sharedPreferences.getBoolean(PREF_DISABLE_ACRA, z);
        } catch (Exception unused) {
            return false;
        }
    }

    public static void init(Application application, ConfigurationBuilder configurationBuilder) {
        init(application, configurationBuilder, true);
    }

    public static void init(Application application, ConfigurationBuilder configurationBuilder, boolean z) {
        try {
            init(application, configurationBuilder.build(), z);
        } catch (ACRAConfigurationException e2) {
            ACRALog aCRALog = log;
            String str = LOG_TAG;
            aCRALog.w(str, "Configuration Error - ACRA not started : " + e2.getMessage());
        }
    }

    public static void init(Application application, ACRAConfiguration aCRAConfiguration) {
        init(application, aCRAConfiguration, true);
    }

    public static void init(Application application, ACRAConfiguration aCRAConfiguration, boolean z) {
        boolean isACRASenderServiceProcess = isACRASenderServiceProcess();
        if (isACRASenderServiceProcess && DEV_LOGGING) {
            log.d(LOG_TAG, "Not initialising ACRA to listen for uncaught Exceptions as this is the SendWorker process and we only send reports, we don't capture them to avoid infinite loops");
        }
        boolean z2 = false;
        boolean z3 = Build.VERSION.SDK_INT >= 8;
        if (!z3) {
            log.w(LOG_TAG, "ACRA 4.7.0+ requires Froyo or greater. ACRA is disabled and will NOT catch crashes or send messages.");
        }
        if (mApplication != null) {
            log.w(LOG_TAG, "ACRA#init called more than once. Won't do anything more.");
            return;
        }
        mApplication = application;
        if (aCRAConfiguration == null) {
            log.e(LOG_TAG, "ACRA#init called but no ACRAConfiguration provided");
            return;
        }
        configProxy = aCRAConfiguration;
        SharedPreferences create = new SharedPreferencesFactory(application, aCRAConfiguration).create();
        new LegacyFileHandler(application, create).updateToCurrentVersionIfNecessary();
        if (z3 && !shouldDisableACRA(create)) {
            z2 = true;
        }
        if (!isACRASenderServiceProcess) {
            ACRALog aCRALog = log;
            String str = LOG_TAG;
            StringBuilder sb = new StringBuilder();
            sb.append("ACRA is ");
            sb.append(z2 ? "enabled" : "disabled");
            sb.append(" for ");
            sb.append(mApplication.getPackageName());
            sb.append(", initializing...");
            aCRALog.i(str, sb.toString());
        }
        errorReporterSingleton = new ErrorReporter(mApplication, configProxy, create, z2, z3, !isACRASenderServiceProcess);
        if (z && !isACRASenderServiceProcess) {
            ApplicationStartupProcessor applicationStartupProcessor = new ApplicationStartupProcessor(mApplication, aCRAConfiguration);
            if (aCRAConfiguration.deleteOldUnsentReportsOnApplicationStart()) {
                applicationStartupProcessor.deleteUnsentReportsFromOldAppVersion();
            }
            if (aCRAConfiguration.deleteUnapprovedReportsOnApplicationStart()) {
                applicationStartupProcessor.deleteAllUnapprovedReportsBarOne();
            }
            if (z2) {
                applicationStartupProcessor.sendApprovedReports();
            }
        }
        AnonymousClass1 r12 = new SharedPreferences.OnSharedPreferenceChangeListener() {
            /* class org.acra.ACRA.AnonymousClass1 */

            public void onSharedPreferenceChanged(SharedPreferences sharedPreferences, String str) {
                if (ACRA.PREF_DISABLE_ACRA.equals(str) || ACRA.PREF_ENABLE_ACRA.equals(str)) {
                    ACRA.getErrorReporter().setEnabled(!ACRA.shouldDisableACRA(sharedPreferences));
                }
            }
        };
        mPrefListener = r12;
        create.registerOnSharedPreferenceChangeListener(r12);
    }
}
