package org.acra;

import android.app.Application;
import android.content.SharedPreferences;
import java.lang.Thread;
import java.util.GregorianCalendar;
import org.acra.builder.LastActivityManager;
import org.acra.builder.NoOpReportPrimer;
import org.acra.builder.ReportBuilder;
import org.acra.builder.ReportExecutor;
import org.acra.builder.ReportPrimer;
import org.acra.collector.ConfigurationCollector;
import org.acra.collector.CrashReportDataFactory;
import org.acra.config.ACRAConfiguration;
import org.acra.log.ACRALog;
import org.acra.model.Element;
import org.acra.util.ApplicationStartupProcessor;
import org.acra.util.ProcessFinisher;

public class ErrorReporter implements Thread.UncaughtExceptionHandler {
    private final ACRAConfiguration config;
    private final Application context;
    private final CrashReportDataFactory crashReportDataFactory;
    private volatile ExceptionHandlerInitializer exceptionHandlerInitializer = new ExceptionHandlerInitializer() {
        /* class org.acra.ErrorReporter.AnonymousClass1 */

        @Override // org.acra.ExceptionHandlerInitializer
        public void initializeExceptionHandler(ErrorReporter errorReporter) {
        }
    };
    private final ReportExecutor reportExecutor;
    private final boolean supportedAndroidVersion;

    ErrorReporter(Application application, ACRAConfiguration aCRAConfiguration, SharedPreferences sharedPreferences, boolean z, boolean z2, boolean z3) {
        Element element;
        Thread.UncaughtExceptionHandler uncaughtExceptionHandler;
        this.context = application;
        this.config = aCRAConfiguration;
        this.supportedAndroidVersion = z2;
        if (aCRAConfiguration.getReportFields().contains(ReportField.INITIAL_CONFIGURATION)) {
            element = ConfigurationCollector.collectConfiguration(application);
        } else {
            element = ACRAConstants.NOT_AVAILABLE;
        }
        CrashReportDataFactory crashReportDataFactory2 = new CrashReportDataFactory(application, aCRAConfiguration, sharedPreferences, new GregorianCalendar(), element);
        this.crashReportDataFactory = crashReportDataFactory2;
        if (z3) {
            uncaughtExceptionHandler = Thread.getDefaultUncaughtExceptionHandler();
            Thread.setDefaultUncaughtExceptionHandler(this);
        } else {
            uncaughtExceptionHandler = null;
        }
        ReportExecutor reportExecutor2 = new ReportExecutor(application, aCRAConfiguration, crashReportDataFactory2, uncaughtExceptionHandler, getReportPrimer(aCRAConfiguration), new ProcessFinisher(application, aCRAConfiguration, new LastActivityManager(application)));
        this.reportExecutor = reportExecutor2;
        reportExecutor2.setEnabled(z);
    }

    private static ReportPrimer getReportPrimer(ACRAConfiguration aCRAConfiguration) {
        try {
            return (ReportPrimer) aCRAConfiguration.reportPrimerClass().newInstance();
        } catch (InstantiationException e2) {
            ACRALog aCRALog = ACRA.log;
            String str = ACRA.LOG_TAG;
            aCRALog.w(str, "Could not construct ReportPrimer from " + aCRAConfiguration.reportPrimerClass() + " - not priming", e2);
            return new NoOpReportPrimer();
        } catch (IllegalAccessException e3) {
            ACRALog aCRALog2 = ACRA.log;
            String str2 = ACRA.LOG_TAG;
            aCRALog2.w(str2, "Could not construct ReportPrimer from " + aCRAConfiguration.reportPrimerClass() + " - not priming", e3);
            return new NoOpReportPrimer();
        }
    }

    private void performDeprecatedReportPriming() {
        try {
            this.exceptionHandlerInitializer.initializeExceptionHandler(this);
        } catch (Exception unused) {
            ACRALog aCRALog = ACRA.log;
            String str = ACRA.LOG_TAG;
            aCRALog.w(str, "Failed to initialize " + this.exceptionHandlerInitializer + " from #handleException");
        }
    }

    @Deprecated
    public void addCustomData(String str, String str2) {
        putCustomData(str, str2);
    }

    public void checkReportsOnApplicationStart() {
        ApplicationStartupProcessor applicationStartupProcessor = new ApplicationStartupProcessor(this.context, this.config);
        if (this.config.deleteOldUnsentReportsOnApplicationStart()) {
            applicationStartupProcessor.deleteUnsentReportsFromOldAppVersion();
        }
        if (this.config.deleteUnapprovedReportsOnApplicationStart()) {
            applicationStartupProcessor.deleteAllUnapprovedReportsBarOne();
        }
        if (this.reportExecutor.isEnabled()) {
            applicationStartupProcessor.sendApprovedReports();
        }
    }

    public void clearCustomData() {
        this.crashReportDataFactory.clearCustomData();
    }

    public String getCustomData(String str) {
        return this.crashReportDataFactory.getCustomData(str);
    }

    public void handleException(Throwable th, boolean z) {
        performDeprecatedReportPriming();
        ReportBuilder reportBuilder = new ReportBuilder();
        reportBuilder.exception(th);
        if (z) {
            reportBuilder.endApplication();
        }
        reportBuilder.build(this.reportExecutor);
    }

    public void handleSilentException(Throwable th) {
        performDeprecatedReportPriming();
        new ReportBuilder().exception(th).sendSilently().build(this.reportExecutor);
    }

    public String putCustomData(String str, String str2) {
        return this.crashReportDataFactory.putCustomData(str, str2);
    }

    public String removeCustomData(String str) {
        return this.crashReportDataFactory.removeCustomData(str);
    }

    public void setEnabled(boolean z) {
        if (this.supportedAndroidVersion) {
            ACRALog aCRALog = ACRA.log;
            String str = ACRA.LOG_TAG;
            StringBuilder sb = new StringBuilder();
            sb.append("ACRA is ");
            sb.append(z ? "enabled" : "disabled");
            sb.append(" for ");
            sb.append(this.context.getPackageName());
            aCRALog.i(str, sb.toString());
            this.reportExecutor.setEnabled(z);
            return;
        }
        ACRA.log.w(ACRA.LOG_TAG, "ACRA 4.7.0+ requires Froyo or greater. ACRA is disabled and will NOT catch crashes or send messages.");
    }

    public void setExceptionHandlerInitializer(ExceptionHandlerInitializer exceptionHandlerInitializer2) {
        if (exceptionHandlerInitializer2 == null) {
            exceptionHandlerInitializer2 = new ExceptionHandlerInitializer() {
                /* class org.acra.ErrorReporter.AnonymousClass2 */

                @Override // org.acra.ExceptionHandlerInitializer
                public void initializeExceptionHandler(ErrorReporter errorReporter) {
                }
            };
        }
        this.exceptionHandlerInitializer = exceptionHandlerInitializer2;
    }

    public void uncaughtException(Thread thread, Throwable th) {
        if (!this.reportExecutor.isEnabled()) {
            this.reportExecutor.handReportToDefaultExceptionHandler(thread, th);
            return;
        }
        try {
            ACRALog aCRALog = ACRA.log;
            String str = ACRA.LOG_TAG;
            aCRALog.e(str, "ACRA caught a " + th.getClass().getSimpleName() + " for " + this.context.getPackageName(), th);
            if (ACRA.DEV_LOGGING) {
                ACRA.log.d(str, "Building report");
            }
            performDeprecatedReportPriming();
            new ReportBuilder().uncaughtExceptionThread(thread).exception(th).endApplication().build(this.reportExecutor);
        } catch (Throwable th2) {
            ACRA.log.e(ACRA.LOG_TAG, "ACRA failed to capture the error - handing off to native error reporter", th2);
            this.reportExecutor.handReportToDefaultExceptionHandler(thread, th);
        }
    }

    public void handleException(Throwable th) {
        handleException(th, false);
    }
}
