package org.acra.collector;

import android.content.Context;
import android.content.SharedPreferences;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import org.acra.ACRA;
import org.acra.ReportField;
import org.acra.builder.ReportBuilder;
import org.acra.collections.ImmutableSet;
import org.acra.config.ACRAConfiguration;
import org.acra.model.Element;
import org.acra.util.PackageManagerWrapper;

public final class CrashReportDataFactory {
    private final Calendar appStartDate;
    private final ACRAConfiguration config;
    private final Context context;
    private final Map<String, String> customParameters = new LinkedHashMap();
    private final Element initialConfiguration;
    private final SharedPreferences prefs;

    public CrashReportDataFactory(Context context2, ACRAConfiguration aCRAConfiguration, SharedPreferences sharedPreferences, Calendar calendar, Element element) {
        this.context = context2;
        this.config = aCRAConfiguration;
        this.prefs = sharedPreferences;
        this.appStartDate = calendar;
        this.initialConfiguration = element;
    }

    private List<Collector> getCollectorsOrdered() {
        ArrayList arrayList = new ArrayList();
        PackageManagerWrapper packageManagerWrapper = new PackageManagerWrapper(this.context);
        arrayList.add(new LogCatCollector(this.config, packageManagerWrapper));
        arrayList.add(new DropBoxCollector(this.context, this.config, packageManagerWrapper));
        arrayList.add(new StacktraceCollector());
        arrayList.add(new TimeCollector(this.appStartDate));
        arrayList.add(new SimpleValuesCollector(this.context));
        arrayList.add(new ConfigurationCollector(this.context, this.initialConfiguration));
        arrayList.add(new MemoryInfoCollector());
        arrayList.add(new ReflectionCollector(this.context, this.config));
        arrayList.add(new DisplayManagerCollector(this.context));
        arrayList.add(new CustomDataCollector(this.customParameters));
        arrayList.add(new SharedPreferencesCollector(this.context, this.config, this.prefs));
        arrayList.add(new DeviceFeaturesCollector(this.context));
        arrayList.add(new SettingsCollector(this.context, this.config));
        arrayList.add(new PackageManagerCollector(packageManagerWrapper));
        arrayList.add(new DeviceIdCollector(this.context, packageManagerWrapper, this.prefs));
        arrayList.add(new LogFileCollector(this.context, this.config));
        arrayList.add(new MediaCodecListCollector());
        arrayList.add(new ThreadCollector());
        return arrayList;
    }

    public void clearCustomData() {
        this.customParameters.clear();
    }

    public CrashReportData createCrashData(ReportBuilder reportBuilder) {
        CrashReportData crashReportData = new CrashReportData();
        try {
            ImmutableSet<ReportField> reportFields = this.config.getReportFields();
            for (Collector collector : getCollectorsOrdered()) {
                try {
                    ReportField[] canCollect = collector.canCollect();
                    for (ReportField reportField : canCollect) {
                        try {
                            if (collector.shouldCollect(reportFields, reportField, reportBuilder)) {
                                crashReportData.put((Enum) reportField, (Object) collector.collect(reportField, reportBuilder));
                            }
                        } catch (RuntimeException e2) {
                            ACRA.log.e(ACRA.LOG_TAG, "Error while retrieving " + reportField.name() + " data", e2);
                        }
                    }
                } catch (RuntimeException e3) {
                    ACRA.log.e(ACRA.LOG_TAG, "Error in collector " + collector.getClass().getSimpleName(), e3);
                }
            }
        } catch (RuntimeException e4) {
            ACRA.log.e(ACRA.LOG_TAG, "Error while retrieving crash data", e4);
        }
        return crashReportData;
    }

    public String getCustomData(String str) {
        return this.customParameters.get(str);
    }

    public String putCustomData(String str, String str2) {
        return this.customParameters.put(str, str2);
    }

    public String removeCustomData(String str) {
        return this.customParameters.remove(str);
    }
}
