package org.acra.collector;

import android.content.Context;
import android.os.Build;
import android.os.DropBoxManager;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Calendar;
import java.util.Locale;
import java.util.Set;
import org.acra.ACRA;
import org.acra.ACRAConstants;
import org.acra.ReportField;
import org.acra.builder.ReportBuilder;
import org.acra.collections.ImmutableSet;
import org.acra.config.ACRAConfiguration;
import org.acra.model.ComplexElement;
import org.acra.model.Element;
import org.acra.util.PackageManagerWrapper;

/* access modifiers changed from: package-private */
public final class DropBoxCollector extends Collector {
    private static final String[] SYSTEM_TAGS = {"system_app_anr", "system_app_wtf", "system_app_crash", "system_server_anr", "system_server_wtf", "system_server_crash", "BATTERY_DISCHARGE_INFO", "SYSTEM_RECOVERY_LOG", "SYSTEM_BOOT", "SYSTEM_LAST_KMSG", "APANIC_CONSOLE", "APANIC_THREADS", "SYSTEM_RESTART", "SYSTEM_TOMBSTONE", "data_app_strictmode"};
    private final ACRAConfiguration config;
    private final Context context;
    private final SimpleDateFormat dateFormat = new SimpleDateFormat("yyyyMMdd'T'HHmmss", Locale.getDefault());
    private final PackageManagerWrapper pm;

    DropBoxCollector(Context context2, ACRAConfiguration aCRAConfiguration, PackageManagerWrapper packageManagerWrapper) {
        super(ReportField.DROPBOX);
        this.context = context2;
        this.config = aCRAConfiguration;
        this.pm = packageManagerWrapper;
    }

    /* access modifiers changed from: package-private */
    @Override // org.acra.collector.Collector
    public Element collect(ReportField reportField, ReportBuilder reportBuilder) {
        try {
            DropBoxManager dropBoxManager = (DropBoxManager) this.context.getSystemService("dropbox");
            Calendar instance = Calendar.getInstance();
            instance.roll(12, -this.config.dropboxCollectionMinutes());
            long timeInMillis = instance.getTimeInMillis();
            this.dateFormat.format(instance.getTime());
            ArrayList<String> arrayList = new ArrayList();
            if (this.config.includeDropBoxSystemTags()) {
                arrayList.addAll(Arrays.asList(SYSTEM_TAGS));
            }
            ImmutableSet<String> additionalDropBoxTags = this.config.additionalDropBoxTags();
            if (!additionalDropBoxTags.isEmpty()) {
                arrayList.addAll(additionalDropBoxTags);
            }
            if (arrayList.isEmpty()) {
                return ACRAConstants.NOT_AVAILABLE;
            }
            ComplexElement complexElement = new ComplexElement();
            for (String str : arrayList) {
                StringBuilder sb = new StringBuilder();
                DropBoxManager.Entry nextEntry = dropBoxManager.getNextEntry(str, timeInMillis);
                if (nextEntry == null) {
                    sb.append("Nothing.");
                    sb.append('\n');
                } else {
                    while (nextEntry != null) {
                        long timeMillis = nextEntry.getTimeMillis();
                        instance.setTimeInMillis(timeMillis);
                        sb.append('@');
                        sb.append(this.dateFormat.format(instance.getTime()));
                        sb.append('\n');
                        String text = nextEntry.getText(500);
                        if (text != null) {
                            sb.append("Text: ");
                            sb.append(text);
                            sb.append('\n');
                        } else {
                            sb.append("Not Text!");
                            sb.append('\n');
                        }
                        nextEntry.close();
                        nextEntry = dropBoxManager.getNextEntry(str, timeMillis);
                    }
                    complexElement.put(str, sb.toString());
                }
            }
            return complexElement;
        } catch (Exception unused) {
            if (ACRA.DEV_LOGGING) {
                ACRA.log.d(ACRA.LOG_TAG, "DropBoxManager not available.");
            }
            return ACRAConstants.NOT_AVAILABLE;
        }
    }

    /* access modifiers changed from: package-private */
    @Override // org.acra.collector.Collector
    public boolean shouldCollect(Set<ReportField> set, ReportField reportField, ReportBuilder reportBuilder) {
        return super.shouldCollect(set, reportField, reportBuilder) && (this.pm.hasPermission("android.permission.READ_LOGS") || Build.VERSION.SDK_INT >= 16);
    }
}
