package org.acra.sender;

import android.content.Context;
import android.content.pm.PackageManager;
import java.io.File;
import java.io.IOException;
import java.util.LinkedList;
import java.util.List;
import org.acra.ACRA;
import org.acra.collector.CrashReportData;
import org.acra.config.ACRAConfiguration;
import org.acra.config.DefaultRetryPolicy;
import org.acra.config.RetryPolicy;
import org.acra.file.CrashReportPersister;
import org.acra.log.ACRALog;
import org.acra.util.IOUtils;
import org.json.JSONException;

final class ReportDistributor {
    private final ACRAConfiguration config;
    private final Context context;
    private final List<ReportSender> reportSenders;

    ReportDistributor(Context context2, ACRAConfiguration aCRAConfiguration, List<ReportSender> list) {
        this.context = context2;
        this.config = aCRAConfiguration;
        this.reportSenders = list;
    }

    private RetryPolicy getRetryPolicy() {
        try {
            return (RetryPolicy) this.config.retryPolicyClass().newInstance();
        } catch (InstantiationException e2) {
            ACRALog aCRALog = ACRA.log;
            String str = ACRA.LOG_TAG;
            aCRALog.e(str, "Failed to create policy instance of class " + this.config.retryPolicyClass().getName(), e2);
            return new DefaultRetryPolicy();
        } catch (IllegalAccessException e3) {
            ACRALog aCRALog2 = ACRA.log;
            String str2 = ACRA.LOG_TAG;
            aCRALog2.e(str2, "Failed to create policy instance of class " + this.config.retryPolicyClass().getName(), e3);
            return new DefaultRetryPolicy();
        }
    }

    private boolean isDebuggable() {
        try {
            if ((this.context.getPackageManager().getApplicationInfo(this.context.getPackageName(), 0).flags & 2) > 0) {
                return true;
            }
            return false;
        } catch (PackageManager.NameNotFoundException unused) {
            return false;
        }
    }

    private void sendCrashReport(CrashReportData crashReportData) {
        if (!isDebuggable() || this.config.sendReportsInDevMode()) {
            LinkedList<RetryPolicy.FailedSender> linkedList = new LinkedList();
            for (ReportSender reportSender : this.reportSenders) {
                try {
                    if (ACRA.DEV_LOGGING) {
                        ACRALog aCRALog = ACRA.log;
                        String str = ACRA.LOG_TAG;
                        aCRALog.d(str, "Sending report using " + reportSender.getClass().getName());
                    }
                    reportSender.send(this.context, crashReportData);
                    if (ACRA.DEV_LOGGING) {
                        ACRALog aCRALog2 = ACRA.log;
                        String str2 = ACRA.LOG_TAG;
                        aCRALog2.d(str2, "Sent report using " + reportSender.getClass().getName());
                    }
                } catch (ReportSenderException e2) {
                    linkedList.add(new RetryPolicy.FailedSender(reportSender, e2));
                }
            }
            if (linkedList.isEmpty()) {
                if (ACRA.DEV_LOGGING) {
                    ACRA.log.d(ACRA.LOG_TAG, "Report was sent by all senders");
                }
            } else if (!getRetryPolicy().shouldRetrySend(this.reportSenders, linkedList)) {
                StringBuilder sb = new StringBuilder("ReportSenders of classes [");
                for (RetryPolicy.FailedSender failedSender : linkedList) {
                    sb.append(failedSender.getSender().getClass().getName());
                    sb.append(", ");
                }
                sb.append("] failed, but Policy marked this task as complete. ACRA will not send this report again.");
                ACRA.log.w(ACRA.LOG_TAG, sb.toString());
            } else {
                throw new ReportSenderException("Policy marked this task as incomplete. ACRA will try to send this report again.", linkedList.get(0).getException());
            }
        }
    }

    public void distribute(File file) {
        ACRALog aCRALog = ACRA.log;
        String str = ACRA.LOG_TAG;
        aCRALog.i(str, "Sending report " + file);
        try {
            sendCrashReport(new CrashReportPersister().load(file));
            IOUtils.deleteReport(file);
        } catch (RuntimeException e2) {
            ACRALog aCRALog2 = ACRA.log;
            String str2 = ACRA.LOG_TAG;
            aCRALog2.e(str2, "Failed to send crash reports for " + file, e2);
            IOUtils.deleteReport(file);
        } catch (IOException e3) {
            ACRALog aCRALog3 = ACRA.log;
            String str3 = ACRA.LOG_TAG;
            aCRALog3.e(str3, "Failed to load crash report for " + file, e3);
            IOUtils.deleteReport(file);
        } catch (JSONException e4) {
            ACRALog aCRALog4 = ACRA.log;
            String str4 = ACRA.LOG_TAG;
            aCRALog4.e(str4, "Failed to load crash report for " + file, e4);
            IOUtils.deleteReport(file);
        } catch (ReportSenderException e5) {
            ACRALog aCRALog5 = ACRA.log;
            String str5 = ACRA.LOG_TAG;
            aCRALog5.e(str5, "Failed to send crash report for " + file, e5);
        }
    }
}
