package org.acra.util;

import android.content.Context;
import android.util.Base64;
import java.io.BufferedOutputStream;
import java.io.IOException;
import java.net.HttpURLConnection;
import java.net.URL;
import java.net.URLEncoder;
import java.security.GeneralSecurityException;
import java.util.Map;
import javax.net.ssl.HttpsURLConnection;
import javax.net.ssl.SSLContext;
import javax.net.ssl.TrustManagerFactory;
import org.acra.ACRA;
import org.acra.config.ACRAConfiguration;
import org.acra.log.ACRALog;
import org.acra.security.KeyStoreHelper;
import org.acra.sender.HttpSender;

public final class HttpRequest {
    private static final String UTF8 = "UTF-8";
    private final ACRAConfiguration config;
    private int connectionTimeOut = 3000;
    private Map<String, String> headers;
    private String login;
    private String password;
    private int socketTimeOut = 3000;

    public HttpRequest(ACRAConfiguration aCRAConfiguration) {
        this.config = aCRAConfiguration;
    }

    public static String getParamsAsFormString(Map<?, ?> map) {
        StringBuilder sb = new StringBuilder();
        for (Map.Entry<?, ?> entry : map.entrySet()) {
            if (sb.length() != 0) {
                sb.append('&');
            }
            Object value = entry.getValue();
            if (value == null) {
                value = "";
            }
            sb.append(URLEncoder.encode(entry.getKey().toString(), UTF8));
            sb.append('=');
            sb.append(URLEncoder.encode(value.toString(), UTF8));
        }
        return sb.toString();
    }

    /* JADX INFO: finally extract failed */
    public void send(Context context, URL url, HttpSender.Method method, String str, HttpSender.Type type) {
        HttpURLConnection httpURLConnection = (HttpURLConnection) url.openConnection();
        if (httpURLConnection instanceof HttpsURLConnection) {
            try {
                TrustManagerFactory instance = TrustManagerFactory.getInstance(TrustManagerFactory.getDefaultAlgorithm());
                instance.init(KeyStoreHelper.getKeyStore(context, this.config));
                SSLContext instance2 = SSLContext.getInstance("TLS");
                instance2.init(null, instance.getTrustManagers(), null);
                ((HttpsURLConnection) httpURLConnection).setSSLSocketFactory(instance2.getSocketFactory());
            } catch (GeneralSecurityException e2) {
                ACRALog aCRALog = ACRA.log;
                String str2 = ACRA.LOG_TAG;
                aCRALog.e(str2, "Could not configure SSL for ACRA request to " + url, e2);
            }
        }
        if (!(this.login == null || this.password == null)) {
            String str3 = new String(Base64.encode((this.login + ':' + this.password).getBytes(UTF8), 2), UTF8);
            StringBuilder sb = new StringBuilder();
            sb.append("Basic ");
            sb.append(str3);
            httpURLConnection.setRequestProperty("Authorization", sb.toString());
        }
        httpURLConnection.setConnectTimeout(this.connectionTimeOut);
        httpURLConnection.setReadTimeout(this.socketTimeOut);
        httpURLConnection.setRequestProperty("User-Agent", String.format("Android ACRA %1$s", "4.9.2"));
        httpURLConnection.setRequestProperty("Accept", "text/html,application/xml,application/json,application/xhtml+xml,text/html;q=0.9,text/plain;q=0.8,image/png,*/*;q=0.5");
        httpURLConnection.setRequestProperty("Content-Type", type.getContentType());
        Map<String, String> map = this.headers;
        if (map != null) {
            for (Map.Entry<String, String> entry : map.entrySet()) {
                httpURLConnection.setRequestProperty(entry.getKey(), entry.getValue());
            }
        }
        byte[] bytes = str.getBytes(UTF8);
        httpURLConnection.setRequestMethod(method.name());
        httpURLConnection.setDoOutput(true);
        httpURLConnection.setFixedLengthStreamingMode(bytes.length);
        System.setProperty("http.keepAlive", "false");
        httpURLConnection.connect();
        BufferedOutputStream bufferedOutputStream = new BufferedOutputStream(httpURLConnection.getOutputStream());
        try {
            bufferedOutputStream.write(bytes);
            bufferedOutputStream.flush();
            IOUtils.safeClose(bufferedOutputStream);
            if (ACRA.DEV_LOGGING) {
                ACRALog aCRALog2 = ACRA.log;
                String str4 = ACRA.LOG_TAG;
                aCRALog2.d(str4, "Sending request to " + url);
            }
            if (ACRA.DEV_LOGGING) {
                ACRALog aCRALog3 = ACRA.log;
                String str5 = ACRA.LOG_TAG;
                aCRALog3.d(str5, "Http " + method.name() + " content : ");
            }
            if (ACRA.DEV_LOGGING) {
                ACRA.log.d(ACRA.LOG_TAG, str);
            }
            int responseCode = httpURLConnection.getResponseCode();
            if (ACRA.DEV_LOGGING) {
                ACRALog aCRALog4 = ACRA.log;
                String str6 = ACRA.LOG_TAG;
                aCRALog4.d(str6, "Request response : " + responseCode + " : " + httpURLConnection.getResponseMessage());
            }
            if (responseCode >= 200 && responseCode < 300) {
                ACRA.log.i(ACRA.LOG_TAG, "Request received by server");
            } else if (responseCode == 408 || responseCode >= 500) {
                ACRALog aCRALog5 = ACRA.log;
                String str7 = ACRA.LOG_TAG;
                aCRALog5.w(str7, "Could not send ACRA Post responseCode=" + responseCode + " message=" + httpURLConnection.getResponseMessage());
                throw new IOException("Host returned error code " + responseCode);
            } else if (responseCode < 400 || responseCode >= 500) {
                ACRALog aCRALog6 = ACRA.log;
                String str8 = ACRA.LOG_TAG;
                aCRALog6.w(str8, "Could not send ACRA Post - request will be discarded. responseCode=" + responseCode + " message=" + httpURLConnection.getResponseMessage());
            } else {
                ACRALog aCRALog7 = ACRA.log;
                String str9 = ACRA.LOG_TAG;
                aCRALog7.w(str9, responseCode + ": Client error - request will be discarded");
            }
            httpURLConnection.disconnect();
        } catch (Throwable th) {
            IOUtils.safeClose(bufferedOutputStream);
            throw th;
        }
    }

    public void setConnectionTimeOut(int i) {
        this.connectionTimeOut = i;
    }

    public void setHeaders(Map<String, String> map) {
        this.headers = map;
    }

    public void setLogin(String str) {
        this.login = str;
    }

    public void setPassword(String str) {
        this.password = str;
    }

    public void setSocketTimeOut(int i) {
        this.socketTimeOut = i;
    }
}
